@@ -177,11 +177,15 @@ class FormatDecisionState(object):
       # Split before the closing bracket if we can.
       return current.node_split_penalty != split_penalty.UNBREAKABLE
 
+    if (current.value == ')' and previous.value == ',' and
+        not _IsSingleElementTuple(current.matching_bracket)):
+      return True
+
     # Prevent splitting before the first argument in compound statements
     # with the exception of function declarations.
     if (style.Get('SPLIT_BEFORE_FIRST_ARGUMENT') and
-        self.line.first.value != 'def' and
-        _IsCompoundStatement(self.line.first)):
+        _IsCompoundStatement(self.line.first) and
+        not _IsFunctionDef(self.line.first)):
       return False
 
     ###########################################################################
@@ -212,6 +216,30 @@ class FormatDecisionState(object):
           # Split before and dedent the closing bracket.
           return self.stack[-1].split_before_closing_bracket
 
+    if (style.Get('SPLIT_BEFORE_EXPRESSION_AFTER_OPENING_PAREN') and
+        current.is_name):
+      # An expression that's surrounded by parens gets split after the opening
+      # parenthesis.
+      def SurroundedByParens(token):
+        """Check if it's an expression surrounded by parentheses."""
+        while token:
+          if token.value == ',':
+            return False
+          if token.value == ')':
+            return not token.next_token
+          if token.OpensScope():
+            token = token.matching_bracket.next_token
+          else:
+            token = token.next_token
+        return False
+
+      if (previous.value == '(' and not previous.is_pseudo_paren and
+          not unwrapped_line.IsSurroundedByBrackets(previous)):
+        pptoken = previous.previous_token
+        if (pptoken and not pptoken.is_name and not pptoken.is_keyword and
+            SurroundedByParens(current)):
+          return True
+
     if (current.is_name or current.is_string) and previous.value == ',':
       # If the list has function calls in it and the full list itself cannot
       # fit on the line, then we want to split. Otherwise, we'll get something
@@ -255,7 +283,16 @@ class FormatDecisionState(object):
         if (opening and opening.value == '(' and opening.previous_token and
             opening.previous_token.is_name):
           # This is a dictionary that's an argument to a function.
-          if self._FitsOnLine(previous, previous.matching_bracket):
+          if (self._FitsOnLine(previous, previous.matching_bracket) and
+              previous.matching_bracket.next_token and
+              not previous.matching_bracket.next_token.ClosesScope() and
+              (not opening.matching_bracket.next_token or
+               opening.matching_bracket.next_token.value != '.')):
+            # Don't split before the key if:
+            #   - The dictionary fits on a line, and
+            #   - The dictionary brackets don't have a closing scope after
+            #     them, and
+            #   - The function call isn't part of a builder-style call.
             return False
       return True
 
@@ -310,8 +347,9 @@ class FormatDecisionState(object):
 
         opening = _GetOpeningBracket(current)
         if opening:
-          arglist_length = (opening.matching_bracket.total_length -
-                            opening.total_length + self.stack[-1].indent)
+          arglist_length = (
+              opening.matching_bracket.total_length - opening.total_length +
+              self.stack[-1].indent)
           return arglist_length > self.column_limit
 
     if style.Get('SPLIT_ARGUMENTS_WHEN_COMMA_TERMINATED'):
@@ -536,8 +574,9 @@ class FormatDecisionState(object):
     if current.value not in {'if', 'for'}:
       last = self.stack[-1]
       last.num_line_splits += 1
-      penalty += (style.Get('SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT') *
-                  last.num_line_splits)
+      penalty += (
+          style.Get('SPLIT_PENALTY_FOR_ADDED_LINE_SPLIT') *
+          last.num_line_splits)
 
     if current.OpensScope() and previous.OpensScope():
       # Prefer to keep opening brackets coalesced (unless it's at the beginning
@@ -580,8 +619,9 @@ class FormatDecisionState(object):
     if (_IsCompoundStatement(self.line.first) and
         (not style.Get('DEDENT_CLOSING_BRACKETS') or
          style.Get('SPLIT_BEFORE_FIRST_ARGUMENT'))):
-      token_indent = (len(self.line.first.whitespace_prefix.split('\n')[-1]) +
-                      style.Get('INDENT_WIDTH'))
+      token_indent = (
+          len(self.line.first.whitespace_prefix.split('\n')[-1]) +
+          style.Get('INDENT_WIDTH'))
       if token_indent == top_of_stack.indent:
         return top_of_stack.indent + style.Get('CONTINUATION_INDENT_WIDTH')
 
@@ -722,6 +762,12 @@ def _IsCompoundStatement(token):
   return token.value in _COMPOUND_STMTS
 
 
+def _IsFunctionDef(token):
+  if token.value == 'async':
+    token = token.next_token
+  return token.value == 'def'
+
+
 def _IsFunctionCallWithArguments(token):
   while token:
     if token.value == '(':
@@ -776,6 +822,21 @@ def _IsLastScopeInLine(current):
   return True
 
 
+def _IsSingleElementTuple(token):
+  """Check if it's a single-element tuple."""
+  close = token.matching_bracket
+  token = token.next_token
+  num_commas = 0
+  while token != close:
+    if token.value == ',':
+      num_commas += 1
+    if token.OpensScope():
+      token = token.matching_bracket
+    else:
+      token = token.next_token
+  return num_commas == 1
+
+
 class _ParenState(object):
   """Maintains the state of the bracket enclosures.
 
